from mkdocs.plugins import BasePlugin
from mkdocs.config import config_options
from xml.etree import ElementTree as ET
import re

class RssDeduplicatePlugin(BasePlugin):

    def on_post_build(self, config):
        # Paths to your RSS feed files
        rss_created_path = config['site_dir'] + '/feed_rss_created.xml'
        rss_updated_path = config['site_dir'] + '/feed_rss_updated.xml'

        # Call the deduplication function on both RSS feed files
        self.remove_duplicates_from_rss(rss_created_path)
        self.remove_duplicates_from_rss(rss_updated_path)
        self.clean_image_tags(rss_created_path)
        self.clean_image_tags(rss_updated_path)

    def clean_image_tags(self, feed_path):
        tree = ET.parse(feed_path)
        root = tree.getroot()

        for item in root.findall('./channel/item'):
            description = item.find('description').text
            # Use regex to remove the width attribute snippet from the description
            cleaned_description = re.sub(r'{\s*width="45%"\s*}', '', description)
            # Update the description text with the cleaned version
            item.find('description').text = cleaned_description

        tree.write(feed_path, encoding='utf-8', xml_declaration=True)

    def remove_duplicates_from_rss(self, feed_path):
        # Parse the XML file
        tree = ET.parse(feed_path)
        root = tree.getroot()

        # Function to remove duplicate entries based on <title> tag
        seen_titles = set()
        for item in root.findall('./channel/item'):
            title = item.find('title').text
            if title in seen_titles:
                root.find('./channel').remove(item)
            else:
                seen_titles.add(title)

        # Save the deduplicated XML to the same file
        tree.write(feed_path, encoding='utf-8', xml_declaration=True)
